@@ -31,6 +31,10 @@ using namespace UCOMMON_NAMESPACE;
 
 LinkedObject *service::callback::runlevels[4] = {NULL, NULL, NULL, NULL};
 unsigned service::callback::count = 0;
+unsigned short service::callback::sip_port = 5060;
+int service::callback::sip_protocol = IPPROTO_UDP;
+int service::callback::sip_family = AF_INET;
+int service::callback::sip_tlsmode = 0;
 condlock_t service::locking;
 service *service::cfg = NULL;
 volatile service::dialmode_t service::dialmode = service::ALL_DIALING;
@@ -39,6 +43,7 @@ static char header[80] = "- welcome";
 static socket_t trap4 = INVALID_SOCKET;
 static socket_t trap6 = INVALID_SOCKET;
 static time_t started = 0l;
+static time_t periodic = 0l;
 
 static size_t xmldecode(char *out, size_t limit, const char *src)
 {
@@ -179,8 +184,10 @@ memalloc(s), root()
 	root.setPointer(NULL);
 	snmpservers = NULL;
 	community = "public";
-	if(!started)
+	if(!started) {
 		time(&started);
+		time(&periodic);
+	}
 
 	env = addNode(&root, "environ", NULL);
 	while(varp && *varp) {
@@ -800,25 +807,37 @@ void service::dumpfile(const char *uid)
 	fclose(fp);
 }
 
-void service::period(const char *uid)
+void service::period(long slice)
 {
-	assert(uid == NULL || *uid != 0);
+	assert(slice > 0);
 
-	keynode *env = getEnviron();
+	time_t now, next;
+	struct tm *dt;
 
-	if(!uid)
-		uid = getValue(env, "USER");
-
-	FILE *fp = process::period(uid);
-	release(env);
-
-	if(!fp) {
-		process::errlog(ERRLOG, "period; cannot access file");
+	slice *= 60l;	// convert to minute intervals...
+	time(&now);
+	next = ((periodic / slice) + 1l) * slice;
+	if(now < next)
 		return;
-	}
 
+	next = (now / slice) * slice;
+
+	FILE *fp = process::statfile();
+
+	if(fp) {
+		dt = localtime(&periodic);
+
+		if(dt->tm_year < 1900)
+			dt->tm_year += 1900;
+
+		fprintf(fp, "%04d-%02d-%02d %02d:%02d:%02d %ld\n",
+			dt->tm_year, dt->tm_mon + 1, dt->tm_mday,
+			dt->tm_hour, dt->tm_min, dt->tm_sec, next - periodic);
+	}
+	periodic = next;
 	stats::period(fp);
-	fclose(fp);
+	if(fp)
+		fclose(fp);
 }
 
 void service::snapshot(const char *uid)
