@@ -130,6 +130,10 @@ public:
 
 		static LinkedObject *runlevels[4];
 		static unsigned count;
+		static unsigned short sip_port;
+		static int sip_protocol;
+		static int sip_family;
+		static int sip_tlsmode;
 
         callback(int level = 0);
         virtual ~callback();
@@ -185,7 +189,7 @@ public:
 	static void dump(FILE *fp, keynode *node, unsigned level);
 	static void snapshot(const char *uid);
 	static void dumpfile(const char *uid);
-	static void period(const char *uid);
+	static void period(long slice);
 	static void result(const char *value);
 	static FILE *open(const char *uid = NULL, const char *cfgpath = NULL);
 	static void startup(void);
