@@ -858,11 +858,6 @@ void server::run(const char *user)
 			continue;
 		}
 
-		if(!stricmp(cp, "period") || !stricmp(cp, "pstats")) {
-			service::period(user);
-			continue;
-		}
-
 		if(!stricmp(cp, "dump")) {
 			service::dumpfile(user);
 			continue;
@@ -876,7 +871,6 @@ void server::run(const char *user)
 		argc = 0;
 		tokens = NULL;
 		while(argc < 64 && NULL != (cp = const_cast<char *>(String::token(cp, &tokens, " \t", "{}")))) {
-			printf("TOKEN %s\n", cp);
 			argv[argc++] = cp;
 		}
 		argv[argc] = NULL;
@@ -893,6 +887,13 @@ invalid:
 			continue;
 		}
 
+		if(!stricmp(argv[0], "period")) {
+			if(argc != 2)
+				goto invalid;
+			service::period(atol(argv[1]));
+			continue;
+		}
+
 		if(!stricmp(argv[0], "address")) {
 			if(argc != 2)
 				goto invalid;
@@ -961,7 +962,7 @@ invalid:
 void server::version(void)
 {
 	printf("SIP Witch " VERSION "\n"
-        "Copyright (C) 2007-2008 David Sugar, Tycho Softworks\n"
+        "Copyright (C) 2007,2008,2009 David Sugar, Tycho Softworks\n"
 		"License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
 		"This is free software: you are free to change and redistribute it.\n"
         "There is NO WARRANTY, to the extent permitted by law.\n");
@@ -976,7 +977,7 @@ void server::usage(void)
 	printf("Usage: sipw [options]\n"
 #endif
 		"Options:\n"
-		"  --help                Display this information\n"
+		"  -help                Display this information\n"
 		"  -foreground           Run server in foreground\n"
 		"  -background           Run server as daemon\n"
 #ifndef _MSWINDOWS_
@@ -1000,6 +1001,7 @@ void server::usage(void)
 		"  -memleak              Find where leaks are with valgrind\n"
 #endif
 	);
+	printf("Report bugs to dyfet@gnutelephony.org\n");
 	exit(0);
 }
 
