@@ -192,10 +192,6 @@ service::callback(1), mapped_reuse<MappedCall>(), TimerQueue()
 	priority = 1;
 	timing = 500;
 	iface = NULL;
-	protocol = IPPROTO_UDP;
-	port = 5060;
-	family = AF_INET;
-	tlsmode = 0;
 	send101 = 1;
 	dumping = false;
 	incoming = false;
@@ -504,11 +500,11 @@ void stack::getInterface(struct sockaddr *iface, struct sockaddr *dest)
 	Socket::getinterface(iface, dest);
 	switch(iface->sa_family) {
 	case AF_INET:
-		((struct sockaddr_in*)(iface))->sin_port = htons(sip.port);
+		((struct sockaddr_in*)(iface))->sin_port = htons(sip_port);
 		break;
 #ifdef	AF_INET6
 	case AF_INET6:
-		((struct sockaddr_in6*)(iface))->sin6_port = htons(sip.port);
+		((struct sockaddr_in6*)(iface))->sin6_port = htons(sip_port);
 		break;
 #endif
 	}
@@ -582,22 +578,22 @@ void stack::start(service *cfg)
 		process::errlog(FAILURE, "calls could not be mapped");
 
 #ifdef	AF_INET6
-	if(family == AF_INET6) {
+	if(sip_family == AF_INET6) {
 		eXosip_enable_ipv6(1);
 		if(!iface)
 			iface = "::0";
 	}
 #endif
 
-	Socket::family(family);
-	if(eXosip_listen_addr(protocol, iface, port, family, tlsmode)) {
+	Socket::family(sip_family);
+	if(eXosip_listen_addr(sip_protocol, iface, sip_port, sip_family, sip_tlsmode)) {
 #ifdef	AF_INET6
-		if(!iface && family == AF_INET6)
+		if(!iface && sip_family == AF_INET6)
 			iface = "::0";
 #endif
 		if(!iface)
 			iface = "*";
-		process::errlog(FAILURE, "sip cannot bind interface %s, port %d", iface, port);
+		process::errlog(FAILURE, "sip cannot bind interface %s, port %d", iface, sip_port);
 	}
 
 	osip_trace_initialize_syslog(TRACE_LEVEL0, (char *)"sipwitch");
@@ -691,7 +687,7 @@ void stack::reload(service *cfg)
 			else if(!stricmp(key, "interface") && !isConfigured()) {
 #ifdef	AF_INET6
 				if(strchr(value, ':') != NULL)
-					family = AF_INET6;
+					sip_family = AF_INET6;
 #endif
 				if(!strcmp(value, ":::") || !strcmp(value, "::0") || !strcmp(value, "::*") || !stricmp(value, "*") || !*value)
 					value = NULL;
@@ -734,14 +730,14 @@ void stack::reload(service *cfg)
 			else if(!stricmp(key, "agent") && !isConfigured())
 				agent = value;
 			else if(!stricmp(key, "port") && !isConfigured())
-				port = atoi(value);
+				sip_port = atoi(value);
 			else if(!stricmp(key, "mapped") && !isConfigured())
 				mapped_calls = atoi(value);
 			else if(!stricmp(key, "transport") && !isConfigured()) {
 				if(!stricmp(value, "tcp") || !stricmp(value, "tls"))
-					protocol = IPPROTO_TCP;
+					sip_protocol = IPPROTO_TCP;
 				else if(!stricmp(value, "tls"))
-					tlsmode = 1;
+					sip_tlsmode = 1;
 			}
 		}
 		sp.next();
@@ -766,7 +762,7 @@ void stack::reload(service *cfg)
 	localnames = localhosts;
 	proxy = new_proxy;
 
-	if(family != AF_INET)
+	if(sip_family != AF_INET)
 		rtpproxy::enableIPV6();
 
 	if(ring_value && ring_value < 100)
@@ -794,7 +790,7 @@ void stack::reload(service *cfg)
 
 const char *stack::getScheme(void)
 {
-	if(sip.tlsmode)
+	if(sip_tlsmode)
 		return "sips";
 	return "sip";
 }
@@ -812,7 +808,7 @@ char *stack::sipPublish(struct sockaddr_internet *addr, char *buf, const char *u
 	if(sip.published == NULL)
 		return sipAddress(addr, buf, user, size);
 
-	if(sip.tlsmode)
+	if(sip_tlsmode)
 		String::set(buf, size, "sips:");
 	else 
 		String::set(buf, size, "sip:");
@@ -832,9 +828,9 @@ char *stack::sipPublish(struct sockaddr_internet *addr, char *buf, const char *u
 
 	String::add(buf, size, sip.published);
 	if(ipv6)
-		snprintf(pbuf, sizeof(pbuf), "]:%u", sip.port);
+		snprintf(pbuf, sizeof(pbuf), "]:%u", sip_port);
 	else
-		snprintf(pbuf, sizeof(pbuf), ":%u", sip.port);
+		snprintf(pbuf, sizeof(pbuf), ":%u", sip_port);
 	String::add(buf, size, pbuf);
 	return buf;
 }
@@ -873,9 +869,9 @@ char *stack::sipAddress(struct sockaddr_internet *addr, char *buf, const char *u
 		return NULL;
 	}
 	if(!port)
-		port = sip.port;
+		port = sip_port;
 
-	if(sip.tlsmode)
+	if(sip_tlsmode)
 		String::set(buf, size, "sips:");
 	else 
 		String::set(buf, size, "sip:");
@@ -905,12 +901,12 @@ Socket::address *stack::getAddress(const char *addr, Socket::address *ap)
 	assert(addr != NULL && *addr != 0);
 
 	char buffer[MAX_URI_SIZE];
-	int family = sip.family;
+	int family = sip_family;
 	const char *svc = "sip";
 	const char *sp;
 	char *ep;
 	int proto = SOCK_DGRAM;
-	if(sip.protocol == IPPROTO_TCP)
+	if(sip_protocol == IPPROTO_TCP)
 		proto = SOCK_STREAM;
 
 	sp = strchr(addr, '<');
