@@ -31,6 +31,16 @@ static const char *control_file;
 static const char *snapshot_file;
 static const char *dump_file;
 
+static void version(void)
+{
+	printf("sipwitch cgi 0.1.0\n"
+        "Copyright (C) 2008 David Sugar, Tycho Softworks\n"
+		"License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
+		"This is free software: you are free to change and redistribute it.\n"
+        "There is NO WARRANTY, to the extent permitted by law.\n");
+    exit(0);
+}
+
 static void error(unsigned err, const char *text)
 {
 	printf(
@@ -537,6 +547,11 @@ use:
 
 extern "C" int main(int argc, char **argv)
 {
+	if(argc > 1) {
+		if(String::equal(argv[1], "-version") || String::equal(argv[1], "--version")) 
+			version();
+	}
+
 #ifdef _MSWINDOWS_
 	char buf[256];
 	GetEnvironmentVariable("APPDATA", buf, 192);
