@@ -93,6 +93,46 @@ static void paddress(struct sockaddr_internet *a1, struct sockaddr_internet *a2)
 	printf("%s:%u\n", buf, p2);
 }
 
+static void periodic(char **argv)
+{
+	char text[80];
+
+	if(argv[1]) {
+		fprintf(stderr, "*** sipwitch: pstats: no arguments used\n");
+		exit(-1);
+	}
+	mapped_view<stats> sta(STAT_MAP);
+	unsigned count = sta.getCount();
+	unsigned index = 0;
+	const volatile stats *map;
+	
+	if(!count) {
+		fprintf(stderr, "*** sipwitch: offline\n");
+		exit(-1);
+	}
+	while(index < count) {
+		map = sta(index++);
+
+		if(!map->id[0])
+			continue;
+
+		if(map->limit)
+			snprintf(text, sizeof(text), "%-12s %05hu", map->id, map->limit);
+		else
+			snprintf(text, sizeof(text), "%-12s -    ", map->id);
+
+		for(unsigned entry = 0; entry < 2; ++entry) {
+			size_t len = strlen(text);
+			snprintf(text + len, sizeof(text) - len, " %07lu %05hu %05hu",
+				map->data[entry].pperiod,
+				map->data[entry].pmin, 
+				map->data[entry].pmax);
+		}
+		printf("%s\n", text);
+	}
+	exit(0);
+}
+
 static void dumpstats(char **argv)
 {
 	char text[80];
@@ -105,8 +145,9 @@ static void dumpstats(char **argv)
 	mapped_view<stats> sta(STAT_MAP);
 	unsigned count = sta.getCount();
 	unsigned index = 0;
-	const volatile stats *map;
+	const stats *map;
 	unsigned current;
+	stats buffer;
 	
 	if(!count) {
 		fprintf(stderr, "*** sipwitch: offline\n");
@@ -114,17 +155,25 @@ static void dumpstats(char **argv)
 	}
 	time(&now);
 	while(index < count) {
-		map = sta(index++);
+		map = const_cast<const stats *>(sta(index++));
 
 		if(!map->id[0])
 			continue;
 
-		snprintf(text, sizeof(text), "%-12s", map->id);
+		do {
+			memcpy(&buffer, map, sizeof(buffer));
+		} while(memcmp(&buffer, map, sizeof(buffer)));
+		map = &buffer;
+
+		if(map->limit)
+			snprintf(text, sizeof(text), "%-12s %05hu", map->id, map->limit);
+		else
+			snprintf(text, sizeof(text), "%-12s -    ", map->id);
+
 		for(unsigned entry = 0; entry < 2; ++entry) {
 			size_t len = strlen(text);
-			snprintf(text + len, sizeof(text) - len, " %09lu %07lu %05hu %05hu",
+			snprintf(text + len, sizeof(text) - len, " %09lu %05hu %05hu",
 				map->data[entry].total,
-				map->data[entry].period, 
 				map->data[entry].current,
 				map->data[entry].peak);
 		}
@@ -296,6 +345,16 @@ static void command(char **argv, unsigned timeout)
 #endif
 }
 
+static void version(void)
+{
+	printf("SIP Witch " VERSION "\n"
+        "Copyright (C) 2007,2008,2009 David Sugar, Tycho Softworks\n"
+		"License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
+		"This is free software: you are free to change and redistribute it.\n"
+        "There is NO WARRANTY, to the extent permitted by law.\n");
+    exit(0);
+}
+
 static void usage(void)
 {
 	printf("usage: sipwitch command\n"
@@ -307,7 +366,8 @@ static void usage(void)
         "  concurrency <level>     Server concurrency level\n"
 		"  down                    Shut down server\n"
 		"  message <ext> <text>    Send text message to extension\n"
-		"  period                  Dump and flush periodic stats\n"
+		"  period <interval>       Collect periodic statistics\n"
+		"  pstats                  Dump periodic statistics\n"
         "  registry                Dump registry\n"
         "  release <ext>           Release registration\n"
 		"  reload                  Reload configuration\n"
@@ -317,6 +377,8 @@ static void usage(void)
         "  state <selection>       Change server state\n"
         "  verbose <level>         Server verbose logging level\n"
 	);		
+
+	printf("Report bugs to dyfet@gnutelephony.org\n");
 	exit(0);
 }
 
@@ -342,6 +404,19 @@ static void level(char **argv, int timeout)
 	command(argv, timeout);
 }
 
+static void period(char **argv)
+{
+	if(!argv[1]) {
+		fprintf(stderr, "*** sipwitch: period: interval missing\n");
+		exit(-1);
+	}
+	if(argv[2]) {
+		fprintf(stderr, "*** sipwitch: period: too many arguments\n");
+		exit(-1);
+	}
+	command(argv, 10);
+}
+
 static void address(char **argv)
 {
 	if(!argv[1]) {
@@ -400,7 +475,6 @@ static void activate(char **argv)
 	command(argv, 10);
 }
 
-
 static void message(char **argv)
 {
 	char buffer[500];
@@ -433,9 +507,11 @@ extern "C" int main(int argc, char **argv)
 		usage();
 
 	++argv;
-	if(String::equal(*argv, "help"))
+	if(String::equal(*argv, "version") || String::equal(*argv, "-version") || String::equal(*argv, "--version"))
+		version();
+	else if(String::equal(*argv, "help") || String::equal(*argv, "-help") || String::equal(*argv, "--help"))
 		usage();
-	else if(String::equal(*argv, "reload") || String::equal(*argv, "check") || String::equal(*argv, "snapshot") || String::equal(*argv, "period") || String::equal(*argv, "pstats"))
+	else if(String::equal(*argv, "reload") || String::equal(*argv, "check") || String::equal(*argv, "snapshot"))
 		single(argv, 30);
 	else if(String::equal(*argv, "down") || String::equal(*argv, "restart") || String::equal(*argv, "abort"))
 		single(argv, 0);
@@ -447,8 +523,12 @@ extern "C" int main(int argc, char **argv)
 		registry(argv);
 	else if(String::equal(*argv, "stats"))
 		dumpstats(argv);
+	else if(String::equal(*argv, "pstats"))
+		periodic(argv);
 	else if(String::equal(*argv, "address"))
 		address(argv);
+	else if(String::equal(*argv, "period"))
+		period(argv);
 	else if(String::equal(*argv, "activate"))
 		activate(argv);
 	else if(String::equal(*argv, "release"))
